==> haskell-emojis-0.1.4.1-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 emojis
version:              0.1.4.1
visibility:           public
id:                   emojis-0.1.4.1-4tXPs3L82IMDXThre4dKn2
key:                  emojis-0.1.4.1-4tXPs3L82IMDXThre4dKn2
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  a434943db90771f786b9c1e682ca20c8
exposed:              True
exposed-modules:      Text.Emoji
hidden-modules:       Trie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/emojis-0.1.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/emojis-0.1.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/emojis-0.1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-emojis
hs-libraries:         HSemojis-0.1.4.1-4tXPs3L82IMDXThre4dKn2
depends:              base-4.17.2.1 containers-0.6.7 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-emojis-0.1.4.1-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 emojis
version:              0.1.4.1
visibility:           public
id:                   emojis-0.1.4.1-Lci0sIqjuZ2LxBbQvFIUVy
key:                  emojis-0.1.4.1-Lci0sIqjuZ2LxBbQvFIUVy
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  337b00f3df3ef151873fdf36f98aaa02
exposed:              True
exposed-modules:      Text.Emoji
hidden-modules:       Trie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/emojis-0.1.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/emojis-0.1.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/emojis-0.1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-emojis
hs-libraries:         HSemojis-0.1.4.1-Lci0sIqjuZ2LxBbQvFIUVy
depends:              base-4.17.2.1 containers-0.6.7 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
